@@ -3,20 +3,19 @@ package Test::Compile;
 use warnings;
 use strict;
 
-use version; our $VERSION = qv("v2.4.1");
+use version; our $VERSION = version->declare("v3.1.0");
 use parent 'Exporter';
-use UNIVERSAL::require;
 use Test::Compile::Internal;
 
 my $Test = Test::Compile::Internal->new();
 
 =head1 NAME
 
-Test::Compile - Check whether Perl files compile correctly.
+Test::Compile - Assert that your Perl files compile OK.
 
 =head1 SYNOPSIS
 
-    use Test::Compile;
+    use Test::Compile qw();
 
     my $test = Test::Compile->new();
     $test->all_files_ok();
@@ -37,7 +36,8 @@ in a module distribution:
     #!perl
     use strict;
     use warnings;
-    use Test::Compile;
+    use Test::Compile qw();
+    
     my $test = Test::Compile->new();
     $test->all_files_ok();
     $test->done_testing();
@@ -226,20 +226,6 @@ sub pl_file_ok {
 
     $name ||= "Compile test for $file";
 
-    # don't "use Devel::CheckOS" because Test::Compile is included by
-    # Module::Install::StandardTests, and we don't want to have to ship
-    # Devel::CheckOS with M::I::T as well.
-    if (Devel::CheckOS->require) {
-
-        # Exclude VMS because $^X doesn't work. In general perl is a symlink to
-        # perlx.y.z but VMS stores symlinks differently...
-        unless (Devel::CheckOS::os_is('OSFeatures::POSIXShellRedirection')
-            and Devel::CheckOS::os_isnt('VMS')) {
-            $Test->skip('Test not compatible with your OS');
-            return;
-        }
-    }
-
     my $ok = $Test->pl_file_compiles($file);
 
     $Test->ok($ok, $name);
@@ -315,7 +301,7 @@ Evan Giles, C<< <egiles@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2020 by the authors.
+Copyright 2007-2021 by the authors.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
