@@ -3,15 +3,14 @@ package Test::Compile::Internal;
 use warnings;
 use strict;
 
-use version; our $VERSION = qv("v2.4.1");
+use version; our $VERSION = version->declare("v3.1.0");
 use File::Spec;
-use UNIVERSAL::require;
 use Test::Builder;
 use IPC::Open3 ();
 
 =head1 NAME
 
-Test::Compile::Internal - Test whether your perl files compile.
+Test::Compile::Internal - Assert that your Perl files compile OK.
 
 =head1 SYNOPSIS
 
@@ -60,7 +59,10 @@ for details.
 sub all_files_ok {
     my ($self, @dirs) = @_;
 
-    if ( $self->all_pm_files_ok(@dirs) && $self->all_pl_files_ok(@dirs) ) {
+    my $pm_ok = $self->all_pm_files_ok(@dirs);
+    my $pl_ok = $self->all_pl_files_ok(@dirs);
+
+    if ( $pm_ok && $pl_ok ) {
         return 1;
     }
 }
@@ -70,7 +72,7 @@ sub all_files_ok {
 
 Checks all the perl module files it can find for compilation errors.
 
-If C<@dirs> is defined then it is taken as an array of directories to
+If C<@dirs> is defined then it is taken as an array of files or directories to
 be searched for perl files, otherwise it searches some default locations
 - see L</all_pm_files(@dirs)>.
 
@@ -167,7 +169,7 @@ sub all_pm_files {
 =item C<all_pl_files(@dirs)>
 
 Searches for and returns a list of perl script files - that is, any files that either
-have a F<.pl> extension, or have no extension but have a perl shebang line.
+have a case insensitive F<.pl>, F<.psgi> extension, or have no extension but have a perl shebang line.
 
 If you provide a list of C<@dirs>, it'll use that as a list of files to process, or
 directories to search for perl scripts.
@@ -190,8 +192,8 @@ sub all_pl_files {
 
     my @pl;
     for my $file ( $self->_find_files(@dirs) ) {
-        if ( $file =~ /\.pl$/ ) {
-            # Files with a .pl extension are perl scripts
+        if ( $file =~ /\.p(?:l|sgi)$/i ) {
+            # Files with .pl or .psgi extensions are perl scripts
             push @pl, $file;
         }
         elsif ( $file =~ /(?:^[^.]+$)/ ) {
@@ -434,7 +436,7 @@ Evan Giles, C<< <egiles@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2020 by the authors.
+Copyright 2007-2021 by the authors.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
